aboutsummaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorchriseth <c@ethdev.com>2016-11-23 22:14:25 +0800
committerchriseth <c@ethdev.com>2016-11-23 23:48:13 +0800
commitc9293f2f2370e16af239f711b56245cf70c29970 (patch)
treeb854ae0a8d0586f6acc8a15e9cb77378c77858f6 /scripts
parenta7c2509adfe57f106cb87ed024925751732b5412 (diff)
downloaddexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.tar
dexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.tar.gz
dexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.tar.bz2
dexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.tar.lz
dexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.tar.xz
dexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.tar.zst
dexon-solidity-c9293f2f2370e16af239f711b56245cf70c29970.zip
Enable the optimizer for test runs.
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/tests.sh9
1 files changed, 7 insertions, 2 deletions
diff --git a/scripts/tests.sh b/scripts/tests.sh
index 5da427d4..dfbda734 100755
--- a/scripts/tests.sh
+++ b/scripts/tests.sh
@@ -65,9 +65,14 @@ $ETH_PATH --test -d /tmp/test &
# The node needs to get a little way into its startup sequence before the IPC
# is available and is ready for the unit-tests to start talking to it.
while [ ! -S /tmp/test/geth.ipc ]; do sleep 2; done
+echo "--> IPC available."
-# And then run the Solidity unit-tests, pointing to that IPC endpoint.
-"$REPO_ROOT"/build/test/soltest -- --ipcpath /tmp/test/geth.ipc
+# And then run the Solidity unit-tests (once without optimization, once with),
+# pointing to that IPC endpoint.
+echo "--> Running tests without optimizer..."
+ "$REPO_ROOT"/build/test/soltest -- --ipcpath /tmp/test/geth.ipc && \
+ echo "--> Running tests WITH optimizer..." && \
+ "$REPO_ROOT"/build/test/soltest -- --optimize --ipcpath /tmp/test/geth.ipc
ERROR_CODE=$?
pkill eth || true
sleep 4